/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with gs_yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum gs_yytokentype {
     T_graph = 258,
     T_node = 259,
     T_edge = 260,
     T_view = 261,
     T_pattern = 262,
     T_search = 263,
     T_input = 264,
     T_open = 265,
     T_close = 266,
     T_insert = 267,
     T_delete = 268,
     T_modify = 269,
     T_lock = 270,
     T_unlock = 271,
     T_segue = 272,
     T_define = 273,
     T_id = 274,
     T_edgeop = 275,
     T_subgraph = 276
   };
#endif
#define T_graph 258
#define T_node 259
#define T_edge 260
#define T_view 261
#define T_pattern 262
#define T_search 263
#define T_input 264
#define T_open 265
#define T_close 266
#define T_insert 267
#define T_delete 268
#define T_modify 269
#define T_lock 270
#define T_unlock 271
#define T_segue 272
#define T_define 273
#define T_id 274
#define T_edgeop 275
#define T_subgraph 276




/* Copy the first part of user declarations.  */
#line 1 "gsgram.ypp"

#pragma prototyped
#include "graphsearch/gscmds.h"


/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 12 "gsgram.ypp"
typedef union YYSTYPE {
			int				i;
			char			*str;
} YYSTYPE;
/* Line 190 of yacc.c.  */
#line 128 "y.tab.c"
# define gs_yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 213 of yacc.c.  */
#line 140 "y.tab.c"

#if ! defined (gs_yyoverflow) || YYERROR_VERBOSE

# ifndef YYFREE
#  define YYFREE free
# endif
# ifndef YYMALLOC
#  define YYMALLOC malloc
# endif

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   else
#    define YYSTACK_ALLOC alloca
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
# endif
#endif /* ! defined (gs_yyoverflow) || YYERROR_VERBOSE */


#if (! defined (gs_yyoverflow) \
     && (! defined (__cplusplus) \
	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union gs_yyalloc
{
  short int gs_yyss;
  YYSTYPE gs_yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union gs_yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined (__GNUC__) && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T gs_yyi;		\
	  for (gs_yyi = 0; gs_yyi < (Count); gs_yyi++)	\
	    (To)[gs_yyi] = (From)[gs_yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T gs_yynewbytes;						\
	YYCOPY (&gs_yyptr->Stack, Stack, gs_yysize);				\
	Stack = &gs_yyptr->Stack;						\
	gs_yynewbytes = gs_yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	gs_yyptr += gs_yynewbytes / sizeof (*gs_yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char gs_yysigned_char;
#else
   typedef short int gs_yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  3
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   60

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  28
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  28
/* YYNRULES -- Number of rules. */
#define YYNRULES  50
/* YYNRULES -- Number of states. */
#define YYNSTATES  85

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   276

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? gs_yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char gs_yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      22,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,    27,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,    26,
       2,    25,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    23,     2,    24,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char gs_yyprhs[] =
{
       0,     0,     3,     5,     9,    10,    12,    14,    16,    18,
      20,    22,    24,    26,    28,    30,    32,    34,    36,    38,
      40,    42,    44,    45,    49,    52,    56,    61,    65,    69,
      73,    76,    79,    82,    88,    94,    99,   107,   113,   118,
     119,   124,   125,   127,   128,   130,   134,   138,   140,   142,
     143
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const gs_yysigned_char gs_yyrhs[] =
{
      29,     0,    -1,    30,    -1,    30,    31,    22,    -1,    -1,
      43,    -1,    46,    -1,    44,    -1,    47,    -1,    45,    -1,
      48,    -1,    33,    -1,    35,    -1,    36,    -1,    37,    -1,
      38,    -1,    39,    -1,    40,    -1,    41,    -1,    42,    -1,
      32,    -1,     1,    -1,    -1,    10,     6,    34,    -1,    55,
      49,    -1,    11,     6,    55,    -1,    14,     6,    55,    49,
      -1,    15,     6,    55,    -1,    16,     6,    55,    -1,    17,
       6,    55,    -1,    18,     7,    -1,    18,     8,    -1,    18,
       9,    -1,    12,    55,     4,    19,    49,    -1,    14,    55,
       4,    19,    49,    -1,    13,    55,     4,    19,    -1,    12,
      55,     5,    19,    19,    19,    49,    -1,    14,    55,     5,
      19,    49,    -1,    13,    55,     5,    19,    -1,    -1,    23,
      50,    51,    24,    -1,    -1,    52,    -1,    -1,    53,    -1,
      52,    54,    53,    -1,    19,    25,    19,    -1,    26,    -1,
      27,    -1,    -1,    19,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned char gs_yyrline[] =
{
       0,    19,    19,    23,    24,    28,    28,    29,    29,    30,
      30,    31,    31,    31,    32,    32,    33,    34,    34,    34,
      35,    36,    39,    42,    45,    48,    51,    54,    57,    60,
      63,    66,    69,    72,    75,    78,    81,    84,    87,    90,
      90,    91,    94,    95,    98,    99,   102,   105,   105,   105,
     107
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const gs_yytname[] =
{
  "$end", "error", "$undefined", "T_graph", "T_node", "T_edge", "T_view",
  "T_pattern", "T_search", "T_input", "T_open", "T_close", "T_insert",
  "T_delete", "T_modify", "T_lock", "T_unlock", "T_segue", "T_define",
  "T_id", "T_edgeop", "T_subgraph", "'\\n'", "'['", "']'", "'='", "';'",
  "','", "$accept", "session", "commands", "command", "nop", "open_view",
  "open_view2", "close_view", "mod_view", "lock_view", "unlock_view",
  "segue", "define_pattern", "define_search", "define_input", "ins_node",
  "mod_node", "del_node", "ins_edge", "mod_edge", "del_edge", "attrlist",
  "@1", "optattrdefs", "attrdefs", "attritem", "optsep", "viewid", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short int gs_yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,    10,    91,    93,    61,    59,    44
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char gs_yyr1[] =
{
       0,    28,    29,    30,    30,    31,    31,    31,    31,    31,
      31,    31,    31,    31,    31,    31,    31,    31,    31,    31,
      31,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    48,    50,
      49,    49,    51,    51,    52,    52,    53,    54,    54,    54,
      55
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char gs_yyr2[] =
{
       0,     2,     1,     3,     0,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     0,     3,     2,     3,     4,     3,     3,     3,
       2,     2,     2,     5,     5,     4,     7,     5,     4,     0,
       4,     0,     1,     0,     1,     3,     3,     1,     1,     0,
       1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char gs_yydefact[] =
{
       4,     0,     0,     1,    21,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    20,    11,    12,    13,    14,
      15,    16,    17,    18,    19,     5,     7,     9,     6,     8,
      10,     0,     0,    50,     0,     0,     0,     0,     0,     0,
       0,    30,    31,    32,     3,    23,    41,    25,     0,     0,
       0,     0,    41,     0,     0,    27,    28,    29,    39,    24,
      41,     0,    35,    38,    26,    41,    41,    43,    33,     0,
      34,    37,     0,     0,    42,    44,    41,     0,    40,    47,
      48,     0,    36,    46,    45
};

/* YYDEFGOTO[NTERM-NUM]. */
static const gs_yysigned_char gs_yydefgoto[] =
{
      -1,     1,     2,    14,    15,    16,    45,    17,    18,    19,
      20,    21,    22,    23,    24,    25,    26,    27,    28,    29,
      30,    59,    67,    73,    74,    75,    81,    34
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -51
static const gs_yysigned_char gs_yypact[] =
{
     -51,     3,    33,   -51,   -51,     5,     8,   -10,   -10,    -2,
      19,    21,    23,    -1,     0,   -51,   -51,   -51,   -51,   -51,
     -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,
     -51,   -10,   -10,   -51,    14,    16,   -10,    31,   -10,   -10,
     -10,   -51,   -51,   -51,   -51,   -51,    15,   -51,    18,    20,
      22,    34,    15,    35,    37,   -51,   -51,   -51,   -51,   -51,
      15,    38,   -51,   -51,   -51,    15,    15,    39,   -51,    40,
     -51,   -51,    17,    28,   -14,   -51,    15,    41,   -51,   -51,
     -51,    39,   -51,   -51,   -51
};

/* YYPGOTO[NTERM-NUM].  */
static const gs_yysigned_char gs_yypgoto[] =
{
     -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,
     -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,   -51,
     -51,   -50,   -51,   -51,   -51,   -41,   -51,    -8
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -50
static const gs_yysigned_char gs_yytable[] =
{
      35,    37,    64,     3,    36,   -49,    41,    42,    43,    33,
      68,    31,    79,    80,    32,    70,    71,    33,    48,    49,
      50,    51,    44,    46,    47,    38,    82,    39,    52,    40,
      55,    56,    57,    -2,     4,    53,    54,    60,    58,    61,
      84,    62,    77,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    78,    63,    65,   -22,    66,    69,    72,    76,
      83
};

static const unsigned char gs_yycheck[] =
{
       8,     9,    52,     0,     6,    19,     7,     8,     9,    19,
      60,     6,    26,    27,     6,    65,    66,    19,     4,     5,
       4,     5,    22,    31,    32,     6,    76,     6,    36,     6,
      38,    39,    40,     0,     1,     4,     5,    19,    23,    19,
      81,    19,    25,    10,    11,    12,    13,    14,    15,    16,
      17,    18,    24,    19,    19,    22,    19,    19,    19,    19,
      19
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char gs_yystos[] =
{
       0,    29,    30,     0,     1,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    31,    32,    33,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,     6,     6,    19,    55,    55,     6,    55,     6,     6,
       6,     7,     8,     9,    22,    34,    55,    55,     4,     5,
       4,     5,    55,     4,     5,    55,    55,    55,    23,    49,
      19,    19,    19,    19,    49,    19,    19,    50,    49,    19,
      49,    49,    19,    51,    52,    53,    19,    25,    24,    26,
      27,    54,    49,    19,    53
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define gs_yyerrok		(gs_yyerrstatus = 0)
#define gs_yyclearin	(gs_yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto gs_yyacceptlab
#define YYABORT		goto gs_yyabortlab
#define YYERROR		goto gs_yyerrorlab


/* Like YYERROR except do call gs_yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto gs_yyerrlab

#define YYRECOVERING()  (!!gs_yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (gs_yychar == YYEMPTY && gs_yylen == 1)				\
    {								\
      gs_yychar = (Token);						\
      gs_yylval = (Value);						\
      gs_yytoken = YYTRANSLATE (gs_yychar);				\
      YYPOPSTACK;						\
      goto gs_yybackup;						\
    }								\
  else								\
    { 								\
      gs_yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (N)								\
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (0)
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
              (Loc).first_line, (Loc).first_column,	\
              (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `gs_yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX gs_yylex (YYLEX_PARAM)
#else
# define YYLEX gs_yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (gs_yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
do {								\
  if (gs_yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      gs_yysymprint (stderr, 					\
                  Type, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| gs_yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
gs_yy_stack_print (short int *bottom, short int *top)
#else
static void
gs_yy_stack_print (bottom, top)
    short int *bottom;
    short int *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (gs_yydebug)							\
    gs_yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
gs_yy_reduce_print (int gs_yyrule)
#else
static void
gs_yy_reduce_print (gs_yyrule)
    int gs_yyrule;
#endif
{
  int gs_yyi;
  unsigned int gs_yylno = gs_yyrline[gs_yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             gs_yyrule - 1, gs_yylno);
  /* Print the symbols being reduced, and their result.  */
  for (gs_yyi = gs_yyprhs[gs_yyrule]; 0 <= gs_yyrhs[gs_yyi]; gs_yyi++)
    YYFPRINTF (stderr, "%s ", gs_yytname [gs_yyrhs[gs_yyi]]);
  YYFPRINTF (stderr, "-> %s\n", gs_yytname [gs_yyr1[gs_yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (gs_yydebug)				\
    gs_yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int gs_yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef gs_yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define gs_yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
gs_yystrlen (const char *gs_yystr)
#   else
gs_yystrlen (gs_yystr)
     const char *gs_yystr;
#   endif
{
  register const char *gs_yys = gs_yystr;

  while (*gs_yys++ != '\0')
    continue;

  return gs_yys - gs_yystr - 1;
}
#  endif
# endif

# ifndef gs_yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define gs_yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
gs_yystpcpy (char *gs_yydest, const char *gs_yysrc)
#   else
gs_yystpcpy (gs_yydest, gs_yysrc)
     char *gs_yydest;
     const char *gs_yysrc;
#   endif
{
  register char *gs_yyd = gs_yydest;
  register const char *gs_yys = gs_yysrc;

  while ((*gs_yyd++ = *gs_yys++) != '\0')
    continue;

  return gs_yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
gs_yysymprint (FILE *gs_yyoutput, int gs_yytype, YYSTYPE *gs_yyvaluep)
#else
static void
gs_yysymprint (gs_yyoutput, gs_yytype, gs_yyvaluep)
    FILE *gs_yyoutput;
    int gs_yytype;
    YYSTYPE *gs_yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) gs_yyvaluep;

  if (gs_yytype < YYNTOKENS)
    YYFPRINTF (gs_yyoutput, "token %s (", gs_yytname[gs_yytype]);
  else
    YYFPRINTF (gs_yyoutput, "nterm %s (", gs_yytname[gs_yytype]);


# ifdef YYPRINT
  if (gs_yytype < YYNTOKENS)
    YYPRINT (gs_yyoutput, gs_yytoknum[gs_yytype], *gs_yyvaluep);
# endif
  switch (gs_yytype)
    {
      default:
        break;
    }
  YYFPRINTF (gs_yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
gs_yydestruct (const char *gs_yymsg, int gs_yytype, YYSTYPE *gs_yyvaluep)
#else
static void
gs_yydestruct (gs_yymsg, gs_yytype, gs_yyvaluep)
    const char *gs_yymsg;
    int gs_yytype;
    YYSTYPE *gs_yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) gs_yyvaluep;

  if (!gs_yymsg)
    gs_yymsg = "Deleting";
  YY_SYMBOL_PRINT (gs_yymsg, gs_yytype, gs_yyvaluep, gs_yylocationp);

  switch (gs_yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int gs_yyparse (void *YYPARSE_PARAM);
# else
int gs_yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int gs_yyparse (void);
#else
int gs_yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The look-ahead symbol.  */
int gs_yychar;

/* The semantic value of the look-ahead symbol.  */
YYSTYPE gs_yylval;

/* Number of syntax errors so far.  */
int gs_yynerrs;



/*----------.
| gs_yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int gs_yyparse (void *YYPARSE_PARAM)
# else
int gs_yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
gs_yyparse (void)
#else
int
gs_yyparse ()

#endif
#endif
{
  
  register int gs_yystate;
  register int gs_yyn;
  int gs_yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int gs_yyerrstatus;
  /* Look-ahead token as an internal (translated) token number.  */
  int gs_yytoken = 0;

  /* Three stacks and their tools:
     `gs_yyss': related to states,
     `gs_yyvs': related to semantic values,
     `gs_yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow gs_yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short int gs_yyssa[YYINITDEPTH];
  short int *gs_yyss = gs_yyssa;
  register short int *gs_yyssp;

  /* The semantic value stack.  */
  YYSTYPE gs_yyvsa[YYINITDEPTH];
  YYSTYPE *gs_yyvs = gs_yyvsa;
  register YYSTYPE *gs_yyvsp;



#define YYPOPSTACK   (gs_yyvsp--, gs_yyssp--)

  YYSIZE_T gs_yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE gs_yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int gs_yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  gs_yystate = 0;
  gs_yyerrstatus = 0;
  gs_yynerrs = 0;
  gs_yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  gs_yyssp = gs_yyss;
  gs_yyvsp = gs_yyvs;


  gs_yyvsp[0] = gs_yylval;

  goto gs_yysetstate;

/*------------------------------------------------------------.
| gs_yynewstate -- Push a new state, which is found in gs_yystate.  |
`------------------------------------------------------------*/
 gs_yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  gs_yyssp++;

 gs_yysetstate:
  *gs_yyssp = gs_yystate;

  if (gs_yyss + gs_yystacksize - 1 <= gs_yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T gs_yysize = gs_yyssp - gs_yyss + 1;

#ifdef gs_yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *gs_yyvs1 = gs_yyvs;
	short int *gs_yyss1 = gs_yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if gs_yyoverflow is a macro.  */
	gs_yyoverflow ("parser stack overflow",
		    &gs_yyss1, gs_yysize * sizeof (*gs_yyssp),
		    &gs_yyvs1, gs_yysize * sizeof (*gs_yyvsp),

		    &gs_yystacksize);

	gs_yyss = gs_yyss1;
	gs_yyvs = gs_yyvs1;
      }
#else /* no gs_yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto gs_yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= gs_yystacksize)
	goto gs_yyoverflowlab;
      gs_yystacksize *= 2;
      if (YYMAXDEPTH < gs_yystacksize)
	gs_yystacksize = YYMAXDEPTH;

      {
	short int *gs_yyss1 = gs_yyss;
	union gs_yyalloc *gs_yyptr =
	  (union gs_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (gs_yystacksize));
	if (! gs_yyptr)
	  goto gs_yyoverflowlab;
	YYSTACK_RELOCATE (gs_yyss);
	YYSTACK_RELOCATE (gs_yyvs);

#  undef YYSTACK_RELOCATE
	if (gs_yyss1 != gs_yyssa)
	  YYSTACK_FREE (gs_yyss1);
      }
# endif
#endif /* no gs_yyoverflow */

      gs_yyssp = gs_yyss + gs_yysize - 1;
      gs_yyvsp = gs_yyvs + gs_yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) gs_yystacksize));

      if (gs_yyss + gs_yystacksize - 1 <= gs_yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", gs_yystate));

  goto gs_yybackup;

/*-----------.
| gs_yybackup.  |
`-----------*/
gs_yybackup:

/* Do appropriate processing given the current state.  */
/* Read a look-ahead token if we need one and don't already have one.  */
/* gs_yyresume: */

  /* First try to decide what to do without reference to look-ahead token.  */

  gs_yyn = gs_yypact[gs_yystate];
  if (gs_yyn == YYPACT_NINF)
    goto gs_yydefault;

  /* Not known => get a look-ahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
  if (gs_yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      gs_yychar = YYLEX;
    }

  if (gs_yychar <= YYEOF)
    {
      gs_yychar = gs_yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      gs_yytoken = YYTRANSLATE (gs_yychar);
      YY_SYMBOL_PRINT ("Next token is", gs_yytoken, &gs_yylval, &gs_yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  gs_yyn += gs_yytoken;
  if (gs_yyn < 0 || YYLAST < gs_yyn || gs_yycheck[gs_yyn] != gs_yytoken)
    goto gs_yydefault;
  gs_yyn = gs_yytable[gs_yyn];
  if (gs_yyn <= 0)
    {
      if (gs_yyn == 0 || gs_yyn == YYTABLE_NINF)
	goto gs_yyerrlab;
      gs_yyn = -gs_yyn;
      goto gs_yyreduce;
    }

  if (gs_yyn == YYFINAL)
    YYACCEPT;

  /* Shift the look-ahead token.  */
  YY_SYMBOL_PRINT ("Shifting", gs_yytoken, &gs_yylval, &gs_yylloc);

  /* Discard the token being shifted unless it is eof.  */
  if (gs_yychar != YYEOF)
    gs_yychar = YYEMPTY;

  *++gs_yyvsp = gs_yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (gs_yyerrstatus)
    gs_yyerrstatus--;

  gs_yystate = gs_yyn;
  goto gs_yynewstate;


/*-----------------------------------------------------------.
| gs_yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
gs_yydefault:
  gs_yyn = gs_yydefact[gs_yystate];
  if (gs_yyn == 0)
    goto gs_yyerrlab;
  goto gs_yyreduce;


/*-----------------------------.
| gs_yyreduce -- Do a reduction.  |
`-----------------------------*/
gs_yyreduce:
  /* gs_yyn is the number of a rule to reduce with.  */
  gs_yylen = gs_yyr2[gs_yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  gs_yyval = gs_yyvsp[1-gs_yylen];


  YY_REDUCE_PRINT (gs_yyn);
  switch (gs_yyn)
    {
        case 21:
#line 36 "gsgram.ypp"
    {gs_abort(IF_ERR_SYNTAX);}
    break;

  case 23:
#line 42 "gsgram.ypp"
    {}
    break;

  case 24:
#line 45 "gsgram.ypp"
    {gs_open_view((gs_yyvsp[-1].str));}
    break;

  case 25:
#line 48 "gsgram.ypp"
    {gs_close_view((gs_yyvsp[0].str));}
    break;

  case 26:
#line 51 "gsgram.ypp"
    {gs_mod_view((gs_yyvsp[-1].str));}
    break;

  case 27:
#line 54 "gsgram.ypp"
    {gs_lock((gs_yyvsp[0].str));}
    break;

  case 28:
#line 57 "gsgram.ypp"
    {gs_unlock((gs_yyvsp[0].str));}
    break;

  case 29:
#line 60 "gsgram.ypp"
    {gs_segue((gs_yyvsp[0].str));}
    break;

  case 30:
#line 63 "gsgram.ypp"
    { gs_define_pattern(); }
    break;

  case 31:
#line 66 "gsgram.ypp"
    { gs_define_search(); }
    break;

  case 32:
#line 69 "gsgram.ypp"
    { gs_define_input(); }
    break;

  case 33:
#line 72 "gsgram.ypp"
    {gs_ins_node((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
    break;

  case 34:
#line 75 "gsgram.ypp"
    {gs_mod_node((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
    break;

  case 35:
#line 78 "gsgram.ypp"
    {gs_del_node((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
    break;

  case 36:
#line 81 "gsgram.ypp"
    {gs_ins_edge((gs_yyvsp[-5].str),(gs_yyvsp[-3].str),(gs_yyvsp[-2].str),(gs_yyvsp[-1].str));}
    break;

  case 37:
#line 84 "gsgram.ypp"
    {gs_mod_edge((gs_yyvsp[-3].str),(gs_yyvsp[-1].str));}
    break;

  case 38:
#line 87 "gsgram.ypp"
    {gs_del_edge((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
    break;

  case 39:
#line 90 "gsgram.ypp"
    {gs_reset_attrs();}
    break;

  case 41:
#line 91 "gsgram.ypp"
    {gs_reset_attrs();}
    break;

  case 46:
#line 102 "gsgram.ypp"
    {gs_append_attr((gs_yyvsp[-2].str),(gs_yyvsp[0].str));}
    break;

  case 50:
#line 107 "gsgram.ypp"
    {(gs_yyval.str) = (gs_yyvsp[0].str); }
    break;


    }

/* Line 1037 of yacc.c.  */
#line 1224 "y.tab.c"

  gs_yyvsp -= gs_yylen;
  gs_yyssp -= gs_yylen;


  YY_STACK_PRINT (gs_yyss, gs_yyssp);

  *++gs_yyvsp = gs_yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  gs_yyn = gs_yyr1[gs_yyn];

  gs_yystate = gs_yypgoto[gs_yyn - YYNTOKENS] + *gs_yyssp;
  if (0 <= gs_yystate && gs_yystate <= YYLAST && gs_yycheck[gs_yystate] == *gs_yyssp)
    gs_yystate = gs_yytable[gs_yystate];
  else
    gs_yystate = gs_yydefgoto[gs_yyn - YYNTOKENS];

  goto gs_yynewstate;


/*------------------------------------.
| gs_yyerrlab -- here on detecting error |
`------------------------------------*/
gs_yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!gs_yyerrstatus)
    {
      ++gs_yynerrs;
#if YYERROR_VERBOSE
      gs_yyn = gs_yypact[gs_yystate];

      if (YYPACT_NINF < gs_yyn && gs_yyn < YYLAST)
	{
	  YYSIZE_T gs_yysize = 0;
	  int gs_yytype = YYTRANSLATE (gs_yychar);
	  const char* gs_yyprefix;
	  char *gs_yymsg;
	  int gs_yyx;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int gs_yyxbegin = gs_yyn < 0 ? -gs_yyn : 0;

	  /* Stay within bounds of both gs_yycheck and gs_yytname.  */
	  int gs_yychecklim = YYLAST - gs_yyn;
	  int gs_yyxend = gs_yychecklim < YYNTOKENS ? gs_yychecklim : YYNTOKENS;
	  int gs_yycount = 0;

	  gs_yyprefix = ", expecting ";
	  for (gs_yyx = gs_yyxbegin; gs_yyx < gs_yyxend; ++gs_yyx)
	    if (gs_yycheck[gs_yyx + gs_yyn] == gs_yyx && gs_yyx != YYTERROR)
	      {
		gs_yysize += gs_yystrlen (gs_yyprefix) + gs_yystrlen (gs_yytname [gs_yyx]);
		gs_yycount += 1;
		if (gs_yycount == 5)
		  {
		    gs_yysize = 0;
		    break;
		  }
	      }
	  gs_yysize += (sizeof ("syntax error, unexpected ")
		     + gs_yystrlen (gs_yytname[gs_yytype]));
	  gs_yymsg = (char *) YYSTACK_ALLOC (gs_yysize);
	  if (gs_yymsg != 0)
	    {
	      char *gs_yyp = gs_yystpcpy (gs_yymsg, "syntax error, unexpected ");
	      gs_yyp = gs_yystpcpy (gs_yyp, gs_yytname[gs_yytype]);

	      if (gs_yycount < 5)
		{
		  gs_yyprefix = ", expecting ";
		  for (gs_yyx = gs_yyxbegin; gs_yyx < gs_yyxend; ++gs_yyx)
		    if (gs_yycheck[gs_yyx + gs_yyn] == gs_yyx && gs_yyx != YYTERROR)
		      {
			gs_yyp = gs_yystpcpy (gs_yyp, gs_yyprefix);
			gs_yyp = gs_yystpcpy (gs_yyp, gs_yytname[gs_yyx]);
			gs_yyprefix = " or ";
		      }
		}
	      gs_yyerror (gs_yymsg);
	      YYSTACK_FREE (gs_yymsg);
	    }
	  else
	    gs_yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	gs_yyerror ("syntax error");
    }



  if (gs_yyerrstatus == 3)
    {
      /* If just tried and failed to reuse look-ahead token after an
	 error, discard it.  */

      if (gs_yychar <= YYEOF)
        {
          /* If at end of input, pop the error token,
	     then the rest of the stack, then return failure.  */
	  if (gs_yychar == YYEOF)
	     for (;;)
	       {

		 YYPOPSTACK;
		 if (gs_yyssp == gs_yyss)
		   YYABORT;
		 gs_yydestruct ("Error: popping",
                             gs_yystos[*gs_yyssp], gs_yyvsp);
	       }
        }
      else
	{
	  gs_yydestruct ("Error: discarding", gs_yytoken, &gs_yylval);
	  gs_yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse look-ahead token after shifting the error
     token.  */
  goto gs_yyerrlab1;


/*---------------------------------------------------.
| gs_yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
gs_yyerrorlab:

#ifdef __GNUC__
  /* Pacify GCC when the user code never invokes YYERROR and the label
     gs_yyerrorlab therefore never appears in user code.  */
  if (0)
     goto gs_yyerrorlab;
#endif

gs_yyvsp -= gs_yylen;
  gs_yyssp -= gs_yylen;
  gs_yystate = *gs_yyssp;
  goto gs_yyerrlab1;


/*-------------------------------------------------------------.
| gs_yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
gs_yyerrlab1:
  gs_yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      gs_yyn = gs_yypact[gs_yystate];
      if (gs_yyn != YYPACT_NINF)
	{
	  gs_yyn += YYTERROR;
	  if (0 <= gs_yyn && gs_yyn <= YYLAST && gs_yycheck[gs_yyn] == YYTERROR)
	    {
	      gs_yyn = gs_yytable[gs_yyn];
	      if (0 < gs_yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (gs_yyssp == gs_yyss)
	YYABORT;


      gs_yydestruct ("Error: popping", gs_yystos[gs_yystate], gs_yyvsp);
      YYPOPSTACK;
      gs_yystate = *gs_yyssp;
      YY_STACK_PRINT (gs_yyss, gs_yyssp);
    }

  if (gs_yyn == YYFINAL)
    YYACCEPT;

  *++gs_yyvsp = gs_yylval;


  /* Shift the error token. */
  YY_SYMBOL_PRINT ("Shifting", gs_yystos[gs_yyn], gs_yyvsp, gs_yylsp);

  gs_yystate = gs_yyn;
  goto gs_yynewstate;


/*-------------------------------------.
| gs_yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
gs_yyacceptlab:
  gs_yyresult = 0;
  goto gs_yyreturn;

/*-----------------------------------.
| gs_yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
gs_yyabortlab:
  gs_yydestruct ("Error: discarding lookahead",
              gs_yytoken, &gs_yylval);
  gs_yychar = YYEMPTY;
  gs_yyresult = 1;
  goto gs_yyreturn;

#ifndef gs_yyoverflow
/*----------------------------------------------.
| gs_yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
gs_yyoverflowlab:
  gs_yyerror ("parser stack overflow");
  gs_yyresult = 2;
  /* Fall through.  */
#endif

gs_yyreturn:
#ifndef gs_yyoverflow
  if (gs_yyss != gs_yyssa)
    YYSTACK_FREE (gs_yyss);
#endif
  return gs_yyresult;
}



